@@ -1,10 +1,9 @@
 ;;; /***************************************************************************
 ;;; *
 ;;; *
-;;; * Copyright (C) 2016, 2017 ng0 <contact.ng0@cryptolab.net>.
+;;; * Copyright (C) 2016, 2017 ng0 <ng0@no-reply.infotropique.org>.
 ;;; *
-;;; * This file is an appendum to gnurl. The author isn't clear about
-;;; * licensing, so in case there are problems, contact them.
+;;; * This file is an appendum to gnurl.
 ;;; *
 ;;; * This software is licensed as described in the file COPYING, which
 ;;; * you should have received as part of this distribution. The terms
@@ -35,32 +34,13 @@
 
 (define %source-dir (dirname (current-filename)))
 
-;; Taken from https://gitlab.com/dustyweb/pubstrate/blob/master/guix.scm
-(define git-file?
-  (let* ((pipe (with-directory-excursion %source-dir
-                 (open-pipe* OPEN_READ "git" "ls-files")))
-         (files (let loop ((lines '()))
-                  (match (read-line pipe)
-                    ((? eof-object?)
-                     (reverse lines))
-                    (line
-                     (loop (cons line lines))))))
-         (status (close-pipe pipe)))
-    (lambda (file stat)
-      (match (stat:type stat)
-        ('directory #t)
-        ((or 'regular 'symlink)
-         (any (cut string-suffix? <> file) files))
-        (_ #f)))))
-
 (define-public gnurl-git
   (package
     (inherit gnurl)
     (name "gnurl-git")
-    (version (string-append "7.53.1-" "dev"))
+    (version (string-append "7.54.1-" "dev"))
     (source
      (local-file %source-dir
                  #:recursive? #t))))
-    ;;#:select? git-file?))
 
 gnurl-git
